pub trait ISolana {
    fn get_ip(&self, pub_key: &String) -> String;
}

pub struct Solana {

}

impl ISolana for Solana {
    fn get_ip(&self, pub_key: &String) -> String{
        String::from("192.168.1.1")
    }
}

impl Solana {
    pub fn new() -> Self {
        Solana{}
    }
}

pub fn resolve() -> impl ISolana {
    Solana::new()
}


